@@ -36,7 +36,10 @@ class ParseHtml:
         self.__init__(self.func)
 
     def get_tags(
-        self, tag_name: str = None, tag_text: str = None, label_text: str = None,
+        self,
+        tag_name: str = None,
+        tag_text: str = None,
+        label_text: str = None,
     ) -> None:
         try:
             tag = self.soup.find_all(tag_name, text=tag_text)[0]
@@ -65,7 +68,10 @@ class ParseHtml:
             self.kargs["labName"] = self.soup.a.text
         if self.soup.find("td", string="Customer institute:"):
             self.kargs["institute"] = (
-                self.soup.find("td", string="Customer institute:",)
+                self.soup.find(
+                    "td",
+                    string="Customer institute:",
+                )
                 .findNextSibling()
                 .get_text()
             )
@@ -161,11 +167,18 @@ class ParseHtml:
 
         return None
 
-    def get_library_prep_parameters(self, label: str = None, key: str = None,) -> None:
+    def get_library_prep_parameters(
+        self,
+        label: str = None,
+        key: str = None,
+    ) -> None:
 
         for tag in self.soup.find_all("label"):
             if tag.text.strip() == label:
-                parameters = pd.read_html(repr(tag.find_next("table")), index_col=0)[0]
+                converter = {"Sample Name": lambda x: str(x)}
+                parameters = pd.read_html(
+                    repr(tag.find_next("table")), index_col=0, converters=converter
+                )[0]
                 parameters = parameters.dropna(how="all")
                 # get rid of spaces in sample name
                 parameters.loc[:, self.index] = parameters[self.index].replace(
@@ -211,9 +224,10 @@ class ParseHtml:
         # collect samples
         for tag in self.soup.find_all("label"):
             if tag.text.strip() == "Upload samples from Excel?":
-                samples_table = pd.read_html(repr(tag.find_next("table")), index_col=0)[
-                    0
-                ]
+                converter = {"Sample Name": lambda x: str(x)}
+                samples_table = pd.read_html(
+                    repr(tag.find_next("table")), index_col=0, converters=converter
+                )[0]
                 samples_table = samples_table.dropna(how="all")
                 # Important: get rid of spaces in sample name, since sample name is
                 # used to construct prefix for seqc outputs
@@ -223,7 +237,6 @@ class ParseHtml:
                 samples_table = samples_table.set_index(self.index)
                 # establish indexed sample names to test for discrepancies
                 self.idx = samples_table.index
-
                 try:
                     assert (
                         not self.idx.empty
@@ -283,12 +296,14 @@ class ParseHtml:
 
         # collect hashtags prep parameters
         self.get_library_prep_parameters(
-            label="Hashtag parameters", key="hashtag_parameters",
+            label="Hashtag parameters",
+            key="hashtag_parameters",
         )
 
         # collect TCR prep parameters
         self.get_library_prep_parameters(
-            label="TCR parameters", key="TCR_parameters",
+            label="TCR parameters",
+            key="TCR_parameters",
         )
 
         return None
