@@ -5,7 +5,9 @@ Core functions to execute sub-commands called from command line.
 """
 import os
 import re
+import shlex
 import sys
+from subprocess import run as runprocess
 from typing import Dict, Optional
 
 from .argsParser import parse_arguments
@@ -61,18 +63,18 @@ def run(
             ]
         )
 
-        import shlex
-        from subprocess import run as runprocess
-
         var = runprocess(shlex.split(cmd), universal_newlines=True, capture_output=True)
         out = var.__dict__
 
     else:
-        jobs = os.path.join(path, "config", args["jobs"])
 
+        jobs = os.path.join(path, "config", args["jobs"])
         cmd = " ".join([sys.executable, execp, "--pem", args["pem"], "--config", jobs])
-        os.system(cmd)
-        out = None
+
+        var = runprocess(shlex.split(cmd), universal_newlines=True, capture_output=True)
+        out = var.__dict__
+        if "Cannot connect to the Docker daemon" in out["stdout"]:
+            out["returncode"] = 1
 
     print("--")
     # change back to old working dir
@@ -134,24 +136,35 @@ def main(argv):
         if not args.tool_path:
             args.tool_path = os.path.join(os.path.expanduser("~"), args.tool_set)
         execp_key = {
-            "sharp": "./submit.sh",
+            "seqc": "seqc_submit_mjobs.py",
             "sera": "sera_submit_mjobs.py",
             "scata": "scata_submit_mjobs.py",
-            "seqc": "seqc_submit_mjobs.py",
+            "Sharp": "./submit-hashtag.sh",
+            "CellRangerVdj": "./submit.sh",
         }
         execp = execp_key[args.tool_set]
         path = args.tool_path
-        if args.tool_set == "sharp":
+        if args.tool_set in ["Sharp", "CellRangerVdj"]:
             hashtag_param = {
                 "secret": os.path.expanduser("~/.cromwell/credentials.json"),
                 "labels": os.path.join("config", args.jobs),
                 "inputs": os.path.join(
                     "config", re.sub("labels.json$", "inputs.json", args.jobs)
                 ),
+                "output": "{}.options.aws.json".format(args.tool_set),
             }
-            args.func(execp, path, hashtag_param, **get_params(args,))
+            out = args.func(execp, path, hashtag_param, **get_params(args,))
         else:
-            args.func(execp, path, **get_params(args,))
+            out = args.func(execp, path, **get_params(args,))
+
+        import json
+
+        print(
+            json.dumps({"args": out["args"], "returncode": out["returncode"]}, indent=4)
+        )
+        print("stdout:\n", out["stdout"])
+        print("stderr:\n", out["stderr"])
+
     else:
         args.func(args)
 
