@@ -281,7 +281,8 @@ def data_transfer(
     }
     # read in results_output.csv file with important information
     try:
-        df = pd.read_csv(results_output, index_col=0)
+        converter = {"Sample": lambda x: str(x)}
+        df = pd.read_csv(results_output, index_col=0, converters=converter)
         # set the target destination directory
         if all(df.destination.isna()):
             # Default to PI user name
@@ -320,7 +321,7 @@ def data_transfer(
 
     print(
         "\n\n{:-^100s}\n\n".format(
-            "Please review the information below before you " "proceed"
+            "Please review the information below before you proceed"
         )
     )
     print(
@@ -407,7 +408,7 @@ def data_transfer(
         )
         statement_2 = (
             "UPDATE `run_records` SET `analysis_storage` = '{}' "
-            "WHERE `rawData_id` IN "
+            "WHERE `state` = 2 AND `rawData_id` IN "
             "(SELECT MAX(`id`) FROM `raw_data` "
             "WHERE `sampleData_id` = {} AND `platform` = {} "
             "GROUP BY `sampleData_id`)".format(
